@@ -1,10 +1,11 @@
 """This is the "nester.py" module and it provides one function called print_lol() that prints lists that may or may not include nested lists."""
-def print_lol(the_list, level=0):
+def print_lol(the_list, indent=False, level=0):
 	"""This function takes a positional argument called "the_list", which is any Python list (of, possibly, nested lists). Each item in the provided list is (recursively) printed to the screen on its own line."""
 	for each_item in the_list: 
 		if isinstance(each_item, list):
 			print_lol(each_item, level+1)
 		else:
-			for num in range(level):
-				print("\t", end='')
+			if indent:
+				for num in range(level):
+					print("\t", end='')
 			print(each_item)
